Jobs
====

.. automodule:: jmstate.jobs
   :no-members:
   :no-undoc-members:
   :no-index:

.. autosummary::
   :toctree: generated/
   :recursive:

   AdamL1Proximal
   ComputeCriteria
   ComputeEBEs
   ComputeFIM
   Fit
   GradStop
   LogParamsHistory
   MCMCDiagnostics
   NoStop
   ParamStop
   PredictSurvLogps
   PredictTrajectories
   PredictY
   Scheduling
   SwitchParams
   ValueStop
